# `modland` Python Package

The `modland` Python package generates georeferencing information for [MODIS/VIIRS Sinusoidal tiles](https://modis-land.gsfc.nasa.gov/MODLAND_grid.html).

[Gregory H. Halverson](https://github.com/gregory-halverson-jpl) (they/them)<br>
[gregory.h.halverson@jpl.nasa.gov](mailto:gregory.h.halverson@jpl.nasa.gov)<br>
NASA Jet Propulsion Laboratory 329G
